Class: Remi::DataTarget::CsvFile
- Inherits:
-
Remi::DataSubject
- Object
- Remi::DataSubject
- Remi::DataTarget::CsvFile
- Defined in:
- lib/remi/data_subject/csv_file.rb
Instance Attribute Summary collapse
-
#csv_options ⇒ Object
readonly
Returns the value of attribute csv_options.
Attributes inherited from Remi::DataSubject
Instance Method Summary collapse
-
#initialize(*args, **kargs, &block) ⇒ CsvFile
constructor
A new instance of CsvFile.
-
#load! ⇒ Object
Public: Performs the load operation, regardless of whether it has already executed.
Methods included from Remi::DataSubject::CsvFile
Methods included from Remi::DataSubject::DataTarget
Methods inherited from Remi::DataSubject
Constructor Details
#initialize(*args, **kargs, &block) ⇒ CsvFile
Returns a new instance of CsvFile.
139 140 141 142 |
# File 'lib/remi/data_subject/csv_file.rb', line 139 def initialize(*args, **kargs, &block) super init_csv_file(*args, **kargs, &block) end |
Instance Attribute Details
#csv_options ⇒ Object (readonly)
Returns the value of attribute csv_options.
144 145 146 |
# File 'lib/remi/data_subject/csv_file.rb', line 144 def end |
Instance Method Details
#load! ⇒ Object
Public: Performs the load operation, regardless of whether it has already executed.
Returns true if the load operation was successful
150 151 152 153 154 |
# File 'lib/remi/data_subject/csv_file.rb', line 150 def load! @logger.info "Writing CSV file #{@path}" df.write_csv @path, true end |